@@ -3,7 +3,8 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   fig.width=6, 
-  fig.height=4
+  fig.height=4,
+  eval=nzchar(Sys.getenv("BUILD_VIGNETTES"))
 )
 oldoption <- options(scipen = 9999)
 options(scipen = 9999)
